==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/Rodzina.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class Rodzina extends GenericDPSObject {
    /**
     * RODZINA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return RODZINA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * RODZINA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Rodzina other = (Rodzina) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/Rodzina.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class Rodzina extends GenericDPSObject {
    /**
     * RODZINA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return RODZINA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * RODZINA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Rodzina other = (Rodzina) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append("]");
        return sb.toString();
    }
}
